#
# Logs
#

class Log < ActiveRecord::Base
	scope :active, -> { where(active: true) }
	scope :inactive, -> { where(active: false) }
	scope :tagged, ->(tag) { where(tags: { tag: tag }) }
	scope :estimated, -> { where("estimation is not null") }

	validates :name, uniqueness: true

	#
	# Tags
	#

	has_and_belongs_to_many :tags

	def tag(tags)
		tags.split(',').each do |t|
			self.tags << Tag.where(tag: t).first_or_create
		end

		return self
	end

	#
	# Series
	#

	has_many :series, :dependent => :destroy

	#
	# Stop
	#

	def stop
		self.deactivate
		self.series.last.stop!
	end

	def stop!
		self.stop
		self.save!
	end

	#
	# Start
	#

	def start(options={})
		self.activate

		attributes = {
			start: Time.now
		}.merge! options

		self.series << Series.new(attributes)
	end

	def start!(options={})
		self.start(options)
		self.save!
	end

	#
	# Activate
	#

	def activate
		self.active = true
	end

	def activate!
		self.activate
		self.save!
	end

	def active?
		self.active == "t"
	end

	#
	# Deactivate
	#

	def deactivate
		self.active = false
	end

	def deactivate!
		self.active = false
		self.save!
	end

	def inactive?
		self.active == "f"
	end

	#
	# Total time
	#

	def total_time
		difference = 0
		self.series.each do |s|
			ending = s.end || Time.now
			difference = difference + s.start.difference(ending)
		end
		difference
	end

	#
	# Creep
	#

	def creep
		self.total_time/self.estimation
	end
end